@@ -1,7 +1,8 @@
 from .date_time_functions import (
     date_time_stamp,
     generate_pdb_name_from_timestamp,
-    generate_prefixed_timestamp
+    generate_prefixed_timestamp,
+    get_timestamp
 )
 from .image_functions import compare_images
 from .system_management_functions import (
